@@ -2,7 +2,7 @@
 *******************************************************************************
 *
 * File:         tsl.c
-* RCS:          $Header: /home/matthew/cvs/bible-kjv-4.10/tsl.c,v 2.4 2003/07/26 09:25:05 matthew Exp $
+* RCS:          $Header: /home/matthew/cvs/bible-kjv-4.10/tsl.c,v 2.10 2005/01/22 17:49:03 matthew Exp $
 * Description:  Text Storage Library
 * Author:       Chip Chapin, Hewlett Packard Company
 * Created:      Thu Aug 24 15:37:16 1989
@@ -32,6 +32,24 @@
 *  Made findfile a separate function in util.c
 *******************************************************************************
 * $Log: tsl.c,v $
+* Revision 2.10  2005/01/22 17:49:03  matthew
+* remove spurious definition of malloc and strtok
+*
+* Revision 2.9  2005/01/22 16:54:13  matthew
+* another cast to make things explicit
+*
+* Revision 2.8  2005/01/22 00:25:08  matthew
+* these are not const
+*
+* Revision 2.7  2005/01/21 19:47:07  matthew
+* include cmp.h which prototypes the compression routines we call
+*
+* Revision 2.6  2003/07/26 11:57:02  matthew
+* tidy up of code (__attribute__ ((noreturn)), remove unused variables, etc
+*
+* Revision 2.5  2003/07/26 11:44:55  matthew
+* add function prototypes to the tsl header file (and add some const modifiers)
+*
 * Revision 2.4  2003/07/26 09:25:05  matthew
 * Move tsl_error declaration to tsl.h
 *
@@ -111,7 +129,10 @@
 
 #include <stdio.h>
 #include <stdarg.h>
+#include <stdlib.h>
+#include <string.h>
 /* #include <search.h> */
+#include "cmp.h"
 #include "tsl.h"
 
 
@@ -122,10 +143,11 @@
 #define FALSE	(0)
 #define TRUE	(1)
 
-static char rcs_ident[]="@(#)$Header: /home/matthew/cvs/bible-kjv-4.10/tsl.c,v 2.4 2003/07/26 09:25:05 matthew Exp $";
-
-char *malloc();
-char *strtok();
+#ifdef __GNUC__
+static char rcs_ident[] __attribute__ ((unused)) ="@(#)$Header: /home/matthew/cvs/bible-kjv-4.10/tsl.c,v 2.10 2005/01/22 17:49:03 matthew Exp $";
+#else
+static char rcs_ident[]="@(#)$Header: /home/matthew/cvs/bible-kjv-4.10/tsl.c,v 2.10 2005/01/22 17:49:03 matthew Exp $";
+#endif
 
 FILE *tfp;			/* Text data file pointer */
 FILE *cfp;			/* Concordance data file pointer */
@@ -159,7 +181,7 @@ int tsl_maxbuffs;		/* Maximum number of buffers we're allowed */
 int tsl_maxbuffusage=0x100000;	/* Max buffer mem usage (bytes)	 */
 
 
-void tsl_error(int fatal, const char *format, ...)
+void tsl_error(const int fatal, const char *format, ...)
 /*----------------------------------------------------------------------
 |   NAME:
 |       tsl_error
@@ -189,7 +211,8 @@ void tsl_error(int fatal, const char *format, ...)
 
 
 
-tsl_scan_concordance( target, sbuf, range_start, range_end )
+int tsl_scan_concordance(const char *target, ref_t *sbuf, ref_t range_start, 
+			 ref_t range_end )
 /*----------------------------------------------------------------------
 |   NAME:
 |       tsl_scan_concordance
@@ -205,20 +228,17 @@ tsl_scan_concordance( target, sbuf, range_start, range_end )
 |           	    	all references.
 |         range_end 	Ending reference.
 |
+|   RETURN VALUE: number of matches found
+|
 |   HISTORY:
 |       921217 cc Initial creation.
 |       921221 cc Revised to use new concordance file format.
 |       930104 cc Added range_start, range_end params.
 |
 \*----------------------------------------------------------------------*/
-
-char *target;
-ref_t *sbuf;
-ref_t range_start;
-ref_t range_end;
 {
     char *word;
-    int index, n;
+    int indx, n;
     int i, j, rsize;
     ref_t ref, curbase;
     unsigned char mapbyte;
@@ -233,16 +253,16 @@ ref_t range_end;
     /* Search through concordance string buffer */
     /* Note that the last string is guaranteed to be "~" */
     word = cf_words;
-    index = 0;
+    indx = 0;
     inx_start = 0;		/* Keep track of index into ref data pool */
                                 /* See makeconcfile.c */
     while ((n=strcmp(word, target)) < 0) {
 	/* This isn't it, but keep looking... */
 	while (*word++) /* advance to next word */
 	    ;
-	rsize = cf_index[index];
+	rsize = cf_index[indx];
 	inx_start += rsize < 0 ? 0 : rsize;
-	index++;	/* index is count of words */
+	indx++;	/* indx is count of words */
     }
     if (n > 0) {
 	/* This isn't it, and we've passed where it would be */
@@ -250,7 +270,7 @@ ref_t range_end;
     }
 
     /* Found it! */
-    rsize = cf_index[index];
+    rsize = cf_index[indx];
     if (rsize < 0) {
 	/* Special case 1: singletons
 	   If a word has only a single ref, then the ref is
@@ -329,7 +349,7 @@ ref_t range_end;
 
 
 
-int tsl_gettext( vn, vc, vb, vbsize )
+int tsl_gettext(const int vn, const int vc, char *vb, const int vbsize )
 /*----------------------------------------------------------------------
 |   NAME:
 |       tsl_gettext
@@ -347,10 +367,6 @@ int tsl_gettext( vn, vc, vb, vbsize )
 |       890829 cc Updated to think about buffer size limits.
 |
 \*----------------------------------------------------------------------*/
-
-int vn, vc;
-char *vb;
-int vbsize;
 {
     int vstart, vsize;
     
@@ -363,7 +379,7 @@ int vbsize;
 	
 
 
-int tsl_printtext( vn, vc )
+int tsl_printtext(const int vn, const int vc)
 /*----------------------------------------------------------------------
 |   NAME:
 |       tsl_printtext
@@ -378,8 +394,6 @@ int tsl_printtext( vn, vc )
 |       890902 cc Creation from tsl_gettext.
 |
 \*----------------------------------------------------------------------*/
-
-int vn, vc;
 {
     int vstart, vsize;
     
@@ -391,7 +405,7 @@ int vn, vc;
 	
 
 
-tsl_textread( start, vsize, vb )
+int tsl_textread(int start, const int vsize, char *vb)
 /*----------------------------------------------------------------------
 |   NAME:
 |       tsl_textread
@@ -413,9 +427,6 @@ tsl_textread( start, vsize, vb )
 |       890904 cc Iterate on multiple windows, instead of recursing.
 |
 \*----------------------------------------------------------------------*/
-
-int start, vsize;
-char *vb;
 {
 #ifdef PLAINTEXT
     /* here's the version that works with a plain text file */
@@ -493,7 +504,7 @@ char *vb;
 		/* This should never happen */
 		tsl_error( TRUE, "Compressed window bigger than window size!");
 	    }
-	    if (fread( tsl_cmpbuffer, 1, cmpwsize, tfp ) != cmpwsize) {
+	    if ((int)fread( tsl_cmpbuffer, 1, cmpwsize, tfp ) != cmpwsize) {
 		tsl_error( TRUE, "Short read" );
 	    }
 	    
@@ -556,7 +567,7 @@ char *vb;
 
 
 
-tsl_init(dfname, path, memlimit)
+void tsl_init(char *dfname,char *path, const int memlimit)
 /*----------------------------------------------------------------------
 |   NAME:
 |       tsl_init
@@ -577,9 +588,6 @@ tsl_init(dfname, path, memlimit)
 |       930423 cc Revised data file headers using Univ_Int.
 |
 \*----------------------------------------------------------------------*/
-
-char *dfname, *path;
-int  memlimit;
 {
     struct tsl_fileheader fh;
     int i;
@@ -690,7 +698,7 @@ int  memlimit;
 } /* tsl_init */
 
 
-tsl_close()
+void tsl_close(void)
 /*----------------------------------------------------------------------
 |   NAME:
 |       tsl_close
@@ -701,9 +709,7 @@ tsl_close()
 |   HISTORY:
 |
 \*----------------------------------------------------------------------*/
-
 {
-    int i;
     struct buffer_rec *bufp, *nbufp;
     
     fclose( tfp);
